bowl.cli_opts package — bowl 0.2.0 documentation

### Navigation

- index
- modules |
- previous |
- bowl 0.2.0 documentation »
- bowl package »

# bowl.cli_opts package

## Submodules

## bowl.cli_opts.add module

This module is the add command of bowl.

Created on 26 May 2014 @author: Charlie Lewis

class `bowl.cli_opts.add.` `Object`

  Bases: `object`

class `bowl.cli_opts.add.` `add`

  Bases: `object`

  This class is responsible for the add command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.connect module

This module is the connect command of bowl.

Created on 15 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.connect.` `connect`

  Bases: `object`

  This class is responsible for the connect command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.delete module

This module is the delete command of bowl.

Created on 22 June 2014 @author: Charlie Lewis

class `bowl.cli_opts.delete.` `delete`

  Bases: `object`

  This class is responsible for the delete command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.disconnect module

This module is the disconnect command of bowl.

Created on 15 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.disconnect.` `disconnect`

  Bases: `object`

  This class is responsible for the disconnect command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.hosts module

This module is the hosts command of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.hosts.` `hosts`

  Bases: `object`

  This class is responsible for the hosts command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.image_import module

This module is the import command of bowl.

Created on 6 June 2014 @author: Charlie Lewis

class `bowl.cli_opts.image_import.` `image_import`

  Bases: `object`

  This class is responsible for the import command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.images module

This module is the images command of bowl.

Created on 22 June 2014 @author: Charlie Lewis

class `bowl.cli_opts.images.` `images`

  Bases: `object`

  This class is responsible for the images command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.info module

This module is the info command of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.info.` `info`

  Bases: `object`

  This class is responsible for the info command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.kill module

This module is the kill command of bowl.

Created on 15 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.kill.` `kill`

  Bases: `object`

  This class is responsible for the kill command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.link module

This module is the link command of bowl.

Created on 14 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.link.` `link`

  Bases: `object`

  This class is responsible for the link command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.list module

This module is the list command of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.list.` `Object`

  Bases: `object`

class `bowl.cli_opts.list.` `list`

  Bases: `object`

  This class is responsible for the list command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.login module

This module is the login command of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.login.` `login`

  Bases: `object`

  This class is responsible for the login command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.logout module

This module is the logout command of bowl.

Created on 29 May 2014 @author: Charlie Lewis

class `bowl.cli_opts.logout.` `logout`

  Bases: `object`

  This class is responsible for the logout command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.logs module

This module is the logs command of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.logs.` `logs`

  Bases: `object`

  This class is responsible for the logs command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.new module

This module is the new command of bowl.

Created on 15 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.new.` `Object`

  Bases: `object`

class `bowl.cli_opts.new.` `new`

  Bases: `object`

  This class is responsible for the new command of the cli.

  static `build_dockerfile`(dockerfile, uuid_dir, main_arg)
  static `build_options`(main_arg)
  static `display_menu`(args, menu, parent, build_dict)
  classmethod `main`(args)
  static `options_menu`(args, menu, config_dict, parent=None)
  static `process_menu`(args, menu, build_dict, parent=None)
  static `query_yes_no`(question, default='no')

    Ask a yes/no question via raw_input() and return their answer.

    “question” is a string that is presented to the user. “default” is the presumed answer if the user just hits <Enter>.

    > It must be “no” (the default), “yes” or None (meaning an answer is required of the user).

    The “answer” return value is one of “yes” or “no”.

## bowl.cli_opts.remove module

This module is the rm command of bowl.

Created on 26 May 2014 @author: Charlie Lewis

class `bowl.cli_opts.remove.` `remove`

  Bases: `object`

  This class is responsible for the rm command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.repositories module

This module is the repositories command of bowl.

Created on 19 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.repositories.` `repositories`

  Bases: `object`

  This class is responsible for the repositories command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.services module

This module is the services command of bowl.

Created on 17 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.services.` `services`

  Bases: `object`

  This class is responsible for the services command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.snapshot module

This module is the snapshot command of bowl.

Created on 15 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.snapshot.` `Object`

  Bases: `object`

class `bowl.cli_opts.snapshot.` `snapshot`

  Bases: `object`

  This class is responsible for the snapshot command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.snapshots module

This module is the snapshots command of bowl.

Created on 17 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.snapshots.` `snapshots`

  Bases: `object`

  This class is responsible for the snapshots command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.start module

This module is the start command of bowl.

Created on 14 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.start.` `start`

  Bases: `object`

  This class is responsible for the start command of the cli.

  classmethod `check_pid`(pid)

    Check for the existence of a unix pid.

  classmethod `main`(args)

## bowl.cli_opts.stop module

This module is the stop command of bowl.

Created on 14 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.stop.` `stop`

  Bases: `object`

  This class is responsible for the stop command of the cli.

  classmethod `check_pid`(pid)

    Check for the existence of a unix pid.

  classmethod `main`(args)

## bowl.cli_opts.unlink module

This module is the unlink command of bowl.

Created on 14 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.unlink.` `unlink`

  Bases: `object`

  This class is responsible for the unlink command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.update module

This module is the update command of bowl.

Created on 17 July 2014 @author: Charlie Lewis

class `bowl.cli_opts.update.` `update`

  Bases: `object`

  This class is responsible for the update command of the cli.

  classmethod `main`(args)

## bowl.cli_opts.version module

This module is the version command of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli_opts.version.` `version`

  Bases: `object`

  This class is responsible for the version command of the cli.

  classmethod `main`(args)

## Module contents

### Navigation

- index
- modules |
- previous |
- bowl 0.2.0 documentation »
- bowl package »